@@ -23,7 +23,8 @@ class TokenService: #pylint: disable=too-many-instance-attributes
         aws_account_id: str,
         aws_role_name: str,
         aws_region: str,
-        gcp_token_lifetime: str = "3600s"
+        gcp_token_lifetime: str = "3600s",
+        gcp_token_scopes: str = "https://www.googleapis.com/auth/cloud-platform"
         ) -> None:
 
         # GCP
@@ -32,6 +33,7 @@ class TokenService: #pylint: disable=too-many-instance-attributes
         self.gcp_provider = gcp_workload_provider
         self.gcp_service_account_email = gcp_service_account_email
         self.gcp_token_lifetime = gcp_token_lifetime
+        self.gcp_token_scopes = gcp_token_scopes
 
         self.gcp_federated_token = None
         self.gcp_sa_token = None
@@ -95,6 +97,6 @@ class TokenService: #pylint: disable=too-many-instance-attributes
             )
 
         # get the SA token
-        self.gcp_sa_token, sa_expire_time = self.utils._get_sa_token(federated_access_token, self.gcp_token_lifetime) #pylint: disable=protected-access
+        self.gcp_sa_token, sa_expire_time = self.utils._get_sa_token(federated_access_token, self.gcp_token_lifetime, self.gcp_token_scopes) #pylint: disable=protected-access
 
         return self.gcp_sa_token, sa_expire_time
